summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/catalogmanagerview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/catalogmanager/catalogmanagerview.h')
-rw-r--r--kbabel/catalogmanager/catalogmanagerview.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kbabel/catalogmanager/catalogmanagerview.h b/kbabel/catalogmanager/catalogmanagerview.h
index 8a405430..d923a3bb 100644
--- a/kbabel/catalogmanager/catalogmanagerview.h
+++ b/kbabel/catalogmanager/catalogmanagerview.h
@@ -79,7 +79,7 @@ class CatalogManagerView : public TQListView
Q_OBJECT
TQ_OBJECT
public:
- CatalogManagerView(KBabel::Project::Ptr project, TQWidget* tqparent=0, const char* name=0);
+ CatalogManagerView(KBabel::Project::Ptr project, TQWidget* parent=0, const char* name=0);
virtual ~CatalogManagerView();
KBabel::CatManSettings settings() const;
@@ -126,14 +126,14 @@ public slots:
* traverses all childs in the directory of the current item
* (including all subdirectories) and displays some statistics
* about the translations. If the item is a file, its
* tqparent directory is used instead.
*/
void statistics();
/**
* traverses all marked childs in the directory of the current item
* (including all subdirectories) and displays some statistics
* about the translations. If the item is a file, its
* tqparent directory is used instead.
*/
void markedStatistics();
/**
@@ -126,14 +126,14 @@ public slots:
* (including all subdirectories) and displays some statistics
* about the translations. If the item is a file, its
- * tqparent directory is used instead.
+ * parent directory is used instead.
*/
void statistics();
@@ -126,14 +126,14 @@ public slots:
* (including all subdirectories) and displays some statistics
* about the translations. If the item is a file, its
- * tqparent directory is used instead.
+ * parent directory is used instead.
*/
void markedStatistics();